@@ -1210,6 +1210,12 @@ class VariableClBuilderInitrdInstall(KernelData):
     def init(self):
         self.label = _("Init RAM fs")
 
+    def list(self, prefix='/', bootdir='boot'):
+        boot_dir = path.join(prefix, bootdir)
+        for x in listDirectory(boot_dir, fullPath=True):
+            if InitrdFile.is_cpio(x):
+                yield x
+
     def filter(self, iterable, version=None):
         for fn in iterable:
             if InitrdFile(fn).get_kernel_version() == version:
